==> react-form-builder-4.9.0.tgz: package/lib/reducer/fields.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { deepFlatten, pipe, clean, head } from './fn-utils';
export var datalistEntries = function datalistEntries(fields) {
  var entries = deepFlatten(fields.map(function (field) {
    var _ref;

    if (field.fields) {
      return datalistEntries(field.fields);
    }

    var entry = field.type === 'picker' && field.datalist && field.datalist.find(function (entry) {
      return entry.value === field.value;
    });
    return entry && (_ref = {}, _ref[field.id] = entry, _ref);
  })).filter(Boolean).reduce(function (acc, entry) {
    return _extends({}, acc, entry);
  }, {});
  return entries;
};
export var fieldsToArrayOfString = function fieldsToArrayOfString(fields) {
  return Object.entries(fieldsToObject(fields)).map(function (field) {
    var id = field[0],
        value = field[1];
    return id + "=" + value;
  });
};
export var fieldsToArrayOfArray = function fieldsToArrayOfArray(fields) {
  return Object.entries(fieldsToObject(fields));
};
export var fieldsToObjectNativeTypes = function fieldsToObjectNativeTypes(fields) {
  var listFields = deepFlatten(fields.map(function (field) {
    var _ref3;

    if (field.fields) {
      return fieldsToArrayOfArray(field.fields).map(function (field) {
        var _ref2;

        var id = field[0],
            value = field[1];
        return _ref2 = {}, _ref2[id] = value || '', _ref2;
      });
    }

    return _ref3 = {}, _ref3[field.id] = field.value || '', _ref3;
  })).reduce(function (acc, field) {
    var _head = head(Object.entries(field)),
        id = _head[0],
        value = _head[1];

    acc[id] = value;
    return acc;
  }, {});
  return listFields;
};
export var fieldsToObject = function fieldsToObject(fields) {
  var listFields = deepFlatten(fields.map(function (field) {
    var _ref5;

    if (field.fields) {
      return fieldsToArrayOfString(field.fields).map(function (string) {
        var _ref4;

        var _string$split = string.split('='),
            key = _string$split[0],
            value = _string$split[1];

        return _ref4 = {}, _ref4[key] = value || '', _ref4;
      });
    }

    return _ref5 = {}, _ref5[field.id] = field.value || '', _ref5;
  })).reduce(function (acc, field) {
    var _head2 = head(Object.entries(field)),
        id = _head2[0],
        value = _head2[1];

    acc[id] = value;
    return acc;
  }, {});
  return listFields;
};
export var fieldsNamesInOrderOfDefinition = function fieldsNamesInOrderOfDefinition(fields) {
  var names = deepFlatten(fields.map(function (field) {
    if (field.fields) {
      return fieldsNamesInOrderOfDefinition(field.fields);
    }

    return field.id;
  }));
  return names;
};
export var fieldsToQP = function fieldsToQP(fields, formID) {
  var qs = "form_id=" + formID + "&" + fieldsToArrayOfString(fields).join('&');
  return qs;
};
export var changeFieldById = function changeFieldById(fields, id, nextField) {
  var nextFields = fields;
  var fieldIndex = fields.findIndex(function (field) {
    return field.id === id;
  });

  if (fieldIndex !== -1) {
    nextFields = [].concat(fields.slice(0, fieldIndex), [_extends({}, fields[fieldIndex], nextField)], fields.slice(fieldIndex + 1));
    return nextFields;
  }

  nextFields = nextFields.map(function (field) {
    if (!field.fields) {
      return field;
    }

    field.fields = changeFieldById(field.fields, id, nextField);
    return field;
  });
  return nextFields;
};
export var pickFieldById = function pickFieldById(fields, id) {
  var field = fields.find(function (field) {
    return field.id === id;
  });

  if (!field) {
    field = pipe(deepFlatten, clean, head)(fields.filter(function (field) {
      return Array.isArray(field.fields);
    }).map(function (field) {
      return pickFieldById(field.fields, id);
    }));
  }

  return field;
};
export var mergeWithInitFields = function mergeWithInitFields(fields, initFields) {};

==> react-form-builder-4.49.0.tgz: package/lib/reducer/fields.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import { deepFlatten, pipe, clean, head } from './fn-utils';
export var datalistEntries = function datalistEntries(fields) {
  var entries = deepFlatten(fields.map(function (field) {
    var _ref;

    if (field.fields) {
      return datalistEntries(field.fields);
    }

    var entry = field.type === 'picker' && field.datalist && field.datalist.find(function (entry) {
      return entry.value === field.value;
    });
    return entry && (_ref = {}, _ref[field.id] = entry, _ref);
  })).filter(Boolean).reduce(function (acc, entry) {
    return _extends({}, acc, entry);
  }, {});
  return entries;
};
export var fieldsToArrayOfString = function fieldsToArrayOfString(fields) {
  return Object.entries(fieldsToObject(fields)).map(function (field) {
    var id = field[0],
        value = field[1];
    return id + "=" + value;
  });
};
export var fieldsToArrayOfStringEncoded = function fieldsToArrayOfStringEncoded(fields) {
  return Object.entries(fieldsToObject(fields)).map(function (field) {
    var id = field[0],
        value = field[1];
    return encodeURIComponent(id) + "=" + encodeURIComponent(value);
  });
};
export var fieldsToArrayOfArray = function fieldsToArrayOfArray(fields) {
  return Object.entries(fieldsToObject(fields));
};
export var fieldsToObjectNativeTypes = function fieldsToObjectNativeTypes(fields) {
  var listFields = deepFlatten(fields.map(function (field) {
    var _ref3;

    if (field.fields) {
      return fieldsToArrayOfArray(field.fields).map(function (field) {
        var _ref2;

        var id = field[0],
            value = field[1];
        return _ref2 = {}, _ref2[id] = value || '', _ref2;
      });
    }

    return _ref3 = {}, _ref3[field.id] = field.value || '', _ref3;
  })).reduce(function (acc, field) {
    var _head = head(Object.entries(field)),
        id = _head[0],
        value = _head[1];

    acc[id] = value;
    return acc;
  }, {});
  return listFields;
};
export var fieldsToObject = function fieldsToObject(fields) {
  var listFields = deepFlatten(fields.map(function (field) {
    var _ref5;

    if (field.fields) {
      return fieldsToArrayOfString(field.fields).map(function (string) {
        var _ref4;

        var _string$split = string.split('='),
            key = _string$split[0],
            value = _string$split[1];

        return _ref4 = {}, _ref4[key] = value || '', _ref4;
      });
    }

    return _ref5 = {}, _ref5[field.id] = field.value || '', _ref5;
  })).reduce(function (acc, field) {
    var _head2 = head(Object.entries(field)),
        id = _head2[0],
        value = _head2[1];

    acc[id] = value;
    return acc;
  }, {});
  return listFields;
};
export var fieldsNamesInOrderOfDefinition = function fieldsNamesInOrderOfDefinition(fields) {
  var names = deepFlatten(fields.map(function (field) {
    if (field.fields) {
      return fieldsNamesInOrderOfDefinition(field.fields);
    }

    return field.id;
  }));
  return names;
};
export var fieldsToQP = function fieldsToQP(fields, formID) {
  var qs = "form_id=" + formID + "&" + fieldsToArrayOfStringEncoded(fields).join('&');
  return qs;
};
export var changeFieldById = function changeFieldById(fields, id, nextField) {
  var nextFields = fields;
  var fieldIndex = fields.findIndex(function (field) {
    return field.id === id;
  });

  if (fieldIndex !== -1) {
    nextFields = [].concat(fields.slice(0, fieldIndex), [_extends({}, fields[fieldIndex], nextField)], fields.slice(fieldIndex + 1));
    return nextFields;
  }

  nextFields = nextFields.map(function (field) {
    if (!field.fields) {
      return field;
    }

    field.fields = changeFieldById(field.fields, id, nextField);
    return field;
  });
  return nextFields;
};
export var pickFieldById = function pickFieldById(fields, id) {
  var field = fields.find(function (field) {
    return field.id === id;
  });

  if (!field) {
    field = pipe(deepFlatten, clean, head)(fields.filter(function (field) {
      return Array.isArray(field.fields);
    }).map(function (field) {
      return pickFieldById(field.fields, id);
    }));
  }

  return field;
};
export var mergeWithInitFields = function mergeWithInitFields(fields, initFields) {};
